import sys

usage_message = """
Usage:
    python -m qlat_grid_config [--cxxflags] [--ldflags] [--libs] [--LD_LIBRARY_PATH] [--eigen-type]
""".strip()

if len(sys.argv) < 2:
    print(usage_message)
    exit()

from qlat_grid_config import get_include_list, get_lib_list, get_new_ld_library_path, get_eigen_type

output_args = []

for arg in sys.argv[1:]:
    if arg == "--cxxflags":
        output_args += [ f"-I{path}" for path in get_include_list() ]
    elif arg == "--ldflags":
        output_args += [ f"-L{path}" for path in get_lib_list() ]
    elif arg == "--libs":
        output_args += [ "-lqlat", "-lqlat-utils", ]
    elif arg == "--LD_LIBRARY_PATH":
        output_args = [ get_new_ld_library_path(), ]
    elif arg == "--eigen-type":
        output_args = [ get_eigen_type(), ]

print(" ".join(output_args))

exit()



import sys

usage_message = """
Usage:
    python3 -m qlat_grid qlat-grid-config ...
""".strip()

if len(sys.argv) < 2:
    print(usage_message)
    exit()

action = sys.argv[1]
sys.argv = sys.argv[1:]

if action == "qlat-grid-config":
    import qlat_grid_config.__main__
else:
    print(usage_message)
    exit()



import os
from qlat_config import qls, qls_all, get_eigen_type, get_dir_list as q_get_dir_list

def get_qlat_grid_dir():
    return os.path.join(os.path.dirname(os.path.dirname(__file__)), 'qlat_grid')

def get_qlat_grid_include():
    return os.path.join(get_qlat_grid_dir(), 'include')

def get_dir_list():
    return [ get_qlat_grid_dir(), ] + q_get_dir_list()

def get_include_list():
    return [ os.path.join(p, 'include') for p in get_dir_list() ]

def get_lib_list():
    return [ os.path.join(p, 'lib') for p in get_dir_list() ]

def get_new_ld_library_path():
    ld_lib_path = os.getenv('LD_LIBRARY_PATH')
    if ld_lib_path is None:
        path_list = []
    else:
        path_list = ld_lib_path.split(':')
    new_path_list = []
    for p in get_lib_list() + path_list:
        if p not in new_path_list:
            new_path_list.append(p)
    return ':'.join(new_path_list)

def get_pxd_list():
    l = []
    for d in get_dir_list():
        fn_list = qls(d)
        for fn in fn_list:
            if fn.endswith(".pxd"):
                l.append(fn)
    return l

def get_header_list():
    l = []
    for d in get_include_list():
        fn_list = qls_all(d)
        for fn in fn_list:
            if fn.endswith(".h"):
                l.append(fn)
    return l
